Package: iheiddown
Title: For Writing Geneva Graduate Institute Documents
Description: A set of tools for writing documents
    according to Geneva Graduate Institute conventions and regulations.
    The most common use is for writing and compiling theses or thesis
    chapters, as drafts or for examination with correct preamble formatting. 
    However, the package also offers users to create HTML presentation
    slides with 'xaringan', complete problem sets, format posters, and, 
    for course instructors, prepare a syllabus.
    The package includes additional functions for institutional color palettes,
    an institutional 'ggplot' theme, a function for counting manuscript words,
    and a bibliographical analysis toolkit.
Date: 2026-05-07
Version: 0.9.9
Authors@R: 
    c(person(given = "James",
           family = "Hollway",
           role = c("aut", "cre", "cph"),
           email = "james.hollway@graduateinstitute.ch",
           comment = c(ORCID = "0000-0002-8361-9647")),
      person(given = "Bernhard",
           family = "Bieri",
           role = "ctb",
           email = "bernhard.bieri@graduateinstitute.ch",
           comment = c(ORCID = "0000-0001-5943-9059")),
      person(given = "Henrique",
           family = "Sposito",
           role = "ctb",
           comment = c(ORCID = "0000-0003-3420-6085"))
    )
URL: https://github.com/iheid-library/iheiddown
BugReports: https://github.com/iheid-library/iheiddown/issues
Depends: R (>= 3.5.0)
License: MIT + file LICENSE
Imports: bookdown, dplyr, ggplot2 (>= 3.4.0), rmarkdown, xaringan,
        crayon, pdftools, rlang, servr, readr, rstudioapi, tibble,
        tidytext, bib2df, stringr, fs, usethis, gender, pagedown
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: testthat, kableExtra, knitr, DT, leaflet, remotes,
        modelsummary, gt
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-05-07 19:05:45 UTC; hollway
Author: James Hollway [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-8361-9647>),
  Bernhard Bieri [ctb] (ORCID: <https://orcid.org/0000-0001-5943-9059>),
  Henrique Sposito [ctb] (ORCID: <https://orcid.org/0000-0003-3420-6085>)
Maintainer: James Hollway <james.hollway@graduateinstitute.ch>
Repository: CRAN
Date/Publication: 2026-05-08 07:31:53 UTC
Built: R 4.5.2; ; 2026-05-08 11:06:14 UTC; unix
