# Generated by roxygen2: do not edit by hand

S3method(print,palette)
export(advdate)
export(bookdown_profile)
export(chapter_pdf)
export(count_words)
export(count_words2)
export(iheid_palette)
export(iheid_palettes)
export(iheiddown_betterland)
export(iheiddown_betterport)
export(iheiddown_poster)
export(mean_pages)
export(mean_year)
export(percent_female)
export(preview_start)
export(preview_stop)
export(problemset_pdf)
export(syllabus_pdf)
export(theme_iheid)
export(thesis_pdf)
export(total_pages)
import(crayon)
import(dplyr)
importFrom(bib2df,bib2df)
importFrom(bookdown,pdf_book)
importFrom(bookdown,preview_chapter)
importFrom(bookdown,render_book)
importFrom(fs,path_dir)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,margin)
importFrom(ggplot2,theme)
importFrom(grDevices,rgb)
importFrom(graphics,image)
importFrom(graphics,par)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(pdftools,pdf_text)
importFrom(readr,read_lines)
importFrom(rlang,.data)
importFrom(rmarkdown,pdf_document)
importFrom(rstudioapi,getSourceEditorContext)
importFrom(servr,daemon_list)
importFrom(servr,daemon_stop)
importFrom(stats,na.omit)
importFrom(stringr,str_detect)
importFrom(stringr,str_split)
importFrom(tibble,as_tibble)
importFrom(tidytext,unnest_tokens)
importFrom(usethis,ui_info)
importFrom(utils,file.edit)
importFrom(utils,install.packages)
importFrom(xaringan,inf_mr)
