This *RMarkdown* template is for writing a Graduate Institute thesis. 

This template's sample content include illustrations of how to write a thesis in *RMarkdown*, 
and largely follows the structure from [this R Markdown workshop](https://ulyngs.github.io/rmarkdown-workshop-2019/).

Congratulations for taking a step further into the lands of open, reproducible science 
by writing your thesis using a tool that allows you to transparently include tables and dynamically generated plots directly from the underlying data. 
Hip hooray!
