---
title: Generate Reproducible & Live HTML and PDF Conference Posters Using RMarkdown
author:
  - name: Gandalf the Grey
    affil: 1
    orcid: '0000-0002-1825-0097'
  - name: Frodo Baggins
    affil: 2
affiliation:
  - num: 1
    address: Department of International Ring Study, Central University of Middle Earth
  - num: 2
    address: Department of Dragon Studies, Northern University of Middle Earth
column_numbers: 3
logoright_name: https&#58;//raw.githubusercontent.com/jhollway/iheiddown/main/man/figures/iheiddown.png
logoleft_name: https&#58;//raw.githubusercontent.com/jhollway/iheiddown/main/man/figures/iheiddown.png
output: 
  iheiddown::iheiddown_poster:
    self_contained: false
bibliography: packages.bib
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = FALSE)
```

# Introduction

Welcome to the `{iheiddown}` twist of the great `{posterdown}` poster template !
This poster, alongside their `#betterposter` versions, allow students and
researchers to create IHEID-themed posters easily within R. The remaining part
of this template allows you to get familiar with its layout. Head over to
`{posterdown}` if you fancy having a look at the original version!

## Objectives

1. Easy to use reproducible poster design. 
2. Integration with R Markdown.
3. Easy transition from `{iheiddown}` to `{pagedown}` report or manuscript documents [@R-pagedown].

# Methods

This package uses the same workflow approach as the R Markdown you know and love. Basically it goes from RMarkdown > Knitr > Markdown > Pandoc > HTML/CSS > PDF. You can even use the bibliography the same way [@iheiddown].

# Results

Usually you want to have a nice table displaying some important results that you have calculated. In `{iheiddown}` this is as easy as using the `{kable}` table formatting you are probably use to as per typical R Markdown formatting.

You can reference tables like so: Table \@ref(tab:mytable). Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aliquam placerat augue at velit tincidunt semper. Donec elementum porta posuere. Nullam interdum, odio at tincidunt feugiat, turpis nisi blandit eros, eu posuere risus felis non quam. Nam eget lorem odio. Duis et aliquet orci. Phasellus nec viverra est.

```{r mytable, out.width='80%'}
knitr::kable(iris[1:10, 1:4], caption = 'Table caption.',align = 'c',"html")
```

Or with figures: Figure \@ref(fig:standard-plot), or Figure \@ref(fig:morefigs).

```{r standard-plot, out.width='80%', fig.align='center', fig.cap='Great figure!', fig.height=5}
plot(mtcars[1:2])
```

```{r morefigs, out.width='80%', echo=TRUE, fig.cap='Amazing, right?!', fig.height=5}
data <- iris

plot(x = data$Sepal.Length, 
     y = data$Sepal.Width, 
     col = data$Species,
     pch = 19, 
     xlab = "Sepal Length (cm)",
     ylab = "Sepal Width (cm)")

```

# Next Steps

Aliquam sed faucibus risus, quis efficitur erat. Vestibulum semper mauris quis tempus eleifend. Aliquam sagittis dictum ipsum, quis viverra ligula eleifend ut. Curabitur sagittis vitae arcu eget faucibus. In non elementum felis. Duis et aliquam nunc. Nunc pulvinar sapien nunc, vel pretium nisi efficitur in. Fusce fringilla maximus leo et maximus. Fusce at ligula laoreet, iaculis mi at, auctor odio. Praesent sed elementum justo. Aenean consectetur risus rhoncus tincidunt efficitur. Praesent dictum mauris at diam maximus maximus [@R-iheiddown].

# Conclusion

Try `{iheiddown}` out! Hopefully you like it!

```{r, include=FALSE}
knitr::write_bib(c('knitr','rmarkdown','iheiddown','pagedown', 'posterdown'), 'packages.bib')
```

# References
