`r if(!knitr:::is_latex_output()) '# References {-}'`

<!-- 
You don't really need to alter this chapter unless you want to change the name of the bibliography section 
to 'Bibliography', 'Literature', or something similar.
Any references included in the chapters will be printed here automatically.
-->

<!-- This quiet code chunk serves as a custom style for the reference section and adds a custom header. Don't change it unless you really want to. -->
```{=latex}
\markboth{References}{References}
```
