% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/palettes.R
\docType{data}
\name{iheid_palettes}
\alias{iheid_palettes}
\title{Complete list of palettes}
\format{
An object of class \code{list} of length 3.
}
\usage{
iheid_palettes
}
\description{
Use \code{\link{iheid_palette}} to construct palettes of desired length.
}
\keyword{datasets}
